@@ -26,6 +26,14 @@ class JsonEncoder(json.JSONEncoder):
             return obj.__dict__
         elif isinstance(obj, Task):
             return obj.__dict__
+        elif isinstance(obj, AddTask):
+            return obj.__dict__
+        elif isinstance(obj, MoveOperation):
+            return obj.__dict__
+        elif isinstance(obj, CompleteOperation):
+            return obj.__dict__
+        elif isinstance(obj, Destination):
+            return obj.value
         else:
             return json.JSONEncoder.default(self, obj)
 
@@ -58,6 +66,12 @@ class JsonDecoder(json.JSONDecoder):
                 return Product(**obj)
             if '_type' in obj and obj['_type'] == 'task':
                 return Task(**obj)
+            if '_type' in obj and obj['_type'] == 'add_task':
+                return AddTask(**obj)
+            if '_type' in obj and obj['_type'] == 'move_operation':
+                return MoveOperation(**obj)
+            if '_type' in obj and obj['_type'] == 'complete_operation':
+                return CompleteOperation(**obj)
         return obj
 
 
