@@ -1,5 +1,3 @@
-import uuid as generate_uuid
-
 
 class Task:
 
@@ -14,7 +12,7 @@ class Task:
         :param uuid: UUID of the task
         """
         self._type = 'task'
-        self.uuid = uuid if uuid != "" else str(generate_uuid.uuid4())
+        self.uuid = uuid
         self.name = name
         self.sub_tasks: [str] = sub_tasks
         self.operations: [str] = operations
